==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/fiscal/model/nota_fiscal_eletronica_data.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from openerp.osv import osv, fields
from funcoes import _fisnfc_get_dados_no_store
from funcoes_nfe import _fisnfc_get_indicador_presenca, _fisnfc_get_tempo_movimentacao_sefaz
from funcoes_nfe import _fisnfc_get_xml

FORMA_IMPRESSAO_DANFE =[
    ('0', 'Sem geração de DANFE'),
    ('1', 'Retrato'),
    ('2', 'Paisagem'),
    ('3', 'DANFE Simplificado'),
    ('4', 'DANFE NFC-e'),
    ('5', 'DANFE NFC-e em mensagem eletrônica')
]
PROCESSO_EMISSAO = [
    ('0', 'Emissao de NF com aplicativo proprio'),
    ('1', 'Emissao de NF avulsa pelo fisco'),
    ('2', 'Emissao de NF avulsa pelo site da SEFAZ'),
    ('3', 'Emissao de NF com aplicativo do fisco')
]
OPERACAO = [
    ('0', 'Operacao sem intermediador'),
    ('1', 'Operacao em site ou plataforma de terceiros'),
]


class fiscal_nf_capa(osv.Model):
    """
    Nota fiscal eletronica
    """
    def default_get(self, cr, uid, fields, context=None):
        context = context and context.copy() or {}
        res = super(fiscal_nf_capa, self).default_get(cr, uid, fields, context)
        if not context.get('import_nfe') and not context.get('nota_referenciada'):
            if res.get('modelo_nf_series_id') and res.get('nf_propria') or \
                    context.get('ctx_nf_propria'):
                nf_propria = self._fisnfc_nota_propria(cr, uid, context)
                vals = self.onchange_modelo_nf(
                    cr, uid, [], res['modelo_nf_series_id'], res['tipo'], nf_propria, context)
                res['modelo_55'] = vals['value'].get('modelo_55')
                if vals['value'].get('modelo_55'):
                    res['nfe_versao_processo_emissao'] = \
                        vals['value'].get('nfe_versao_processo_emissao')
                    res['nfe_forma_emissao'] = vals['value'].get('nfe_forma_emissao')
                    res['finalidade_emissao'] = vals['value'].get('finalidade_emissao')
                    res['nfe_processo_emissao'] = vals['value'].get('nfe_processo_emissao')
                    res['nfe_forma_impressao_danfe'] = \
                        vals['value'].get('nfe_forma_impressao_danfe')
                    res['fisnfc_nfe_status_configuracao_homologacao'] = \
                        vals['value'].get('fisnfc_nfe_status_configuracao_homologacao')
                    res['fisnfc_nfe_status_configuracao_producao'] = \
                        vals['value'].get('fisnfc_nfe_status_configuracao_producao')
        return res

    _inherit = 'fiscal.nf.capa'
    _columns = {
        'modelo_55': fields.boolean('modelo_55'),
        'gerar_xml': fields.boolean('gerar xml'),
        'finalidade_emissao': fields.selection(
            [('1', 'Normal'), ('2', 'Complementar'), ('3', 'Ajuste'),('4','Devolucao')],
            'Finalidade emissao', size=1),
        'fisnfc_nfe_indicador_presenca': fields.selection(
            _fisnfc_get_indicador_presenca, 'Indicador de presenca do comprador',
            type='char', size=1,
            help='Indicador de presenca do comprador no estabelecimento comercial no momento da '
                 'operacao.'),
        'nfe_lote': fields.char('Lote de autorizacao', size=15),
        'nfe_status': fields.char('Status NF-e', size=255),
        'nfe_xml_proc': fields.function(_fisnfc_get_xml, type='text'),
        'nfe_xml_auto': fields.text('XML de autorizacao'),
        'nfe_protocolo': fields.char('Protocolo de autorizacao', size=15),
        'nfe_xml_gerado': fields.text('XML da NF'),
        'nfe_chave_acesso': fields.char('Chave de acesso', size=44),
        'nfe_chave_cte': fields.char('Chave CT-e', size=44),
        'nfe_forma_emissao': fields.selection([
            ('1', 'Normal'), ('2', 'Contigencia')], 'Nfe forma emissao', size=1, select=True),
        'nfe_xml_cancelamento': fields.text('Xml Cancelamento'),
        'nfe_processo_emissao': fields.selection(PROCESSO_EMISSAO, 'Nfe processo emissao', size=1),
        'nfe_forma_impressao_danfe': fields.selection(
            FORMA_IMPRESSAO_DANFE, 'Nfe forma impressao danfe', size=1),
        'nfe_protocolo_cancelamento': fields.char('Nfe Protocolo Cancelamento', size=15),
        'nfe_versao_processo_emissao': fields.char('Nfe versao processo emissao', size=20),
        'fisnfc_nfe_retorno_situacao_nfe': fields.text('XML Situacao NF-e'),
        'fisnfc_nfe_situacao_nfe_motivo': fields.text('Situacao NF-e'),
        'fisnfc_nfe_situacao_regular': fields.selection([
            ('R', 'Regular'), ('I', 'Irregular'), ('S', 'Sem Resposta')], 'Situacao NF-e', size=1),
        'fisnfc_nfe_xml_situacao_cliente': fields.text('Retorno XML Situacao Cliente'),
        'fisnfc_nfe_situacao_motivo': fields.text('Situacao Cliente'),
        'fisnfc_nfe_situacao_cliente': fields.selection([
            ('R', 'Regular'), ('I', 'Irregular'), ('S', 'Sem Resposta')], 'Situacao', size=1),
        'fisnfc_nfe_xml_correcao': fields.text('XML Correcao'),
        'fisnfc_nfe_protocolo_correcao': fields.char('Nfe Protocolo Correcao', size=15),
        'fisnfc_nfe_status_correcao': fields.text('Status Correcao'),
        'fisnfc_nfe_status_configuracao_homologacao': fields.text('Status NF-e Homologacao'),
        'fisnfc_nfe_status_configuracao_producao': fields.text('Status NF-e Producao'),
        'fisnfc_permissao_voltar_esboco': fields.function(
            _fisnfc_get_dados_no_store, type='boolean', method=True, multi='dados_no',
            string='Permissao para voltar para esboco'),
        'create_date': fields.datetime('Data de criacao', readonly=True),
        'write_date': fields.datetime('Data ultima alteracao', readonly=True),
        'nfe_observacao':fields.text('Observacoes da nota fiscal'),
        'nfe_tempo_movimentacao_sefaz': fields.function(
            _fisnfc_get_tempo_movimentacao_sefaz, method=True, digits=(3, 2),
            string='Tempo movimentacao SEFAZ',
            help='Informa o tempo decorrido em horas entre a primeira movimentacao e os demais '
                 'processos (inutilizacao, cancelamento, outros envios) envolvendo notas fiscais '
                 'eletronicas junto a SEFAZ.'),
        'fisnfc_evento_ids': fields.one2many('fiscal.evento', 'fiseve_nf_id', 'Evento'),
        'fisnfc_nfe_indintermed': fields.selection(
            OPERACAO, 'Intermediador', size=1,
            help='Identifique se a operacao utiliza intermediadores'),
        'fisnfc_nfe_intermediador_cnpj': fields.char('CNPJ do intermediador', size=14),
        'fisnfc_nfe_intermediador_identificador': fields.char(
            'Identificador do intermediador', size=20),
    }
    _defaults = {
        'fisnfc_nfe_situacao_regular': 'S',
        'fisnfc_nfe_situacao_cliente': 'S',
        'nfe_status': '0',
        'gerar_xml': lambda *a: True,
        'nfe_processo_emissao': '0',
        'fisnfc_nfe_indicador_presenca': lambda sf, cr, us, cx: sf.pool.get(
            'adm.utils').admutl_get_parametros(
            cr, us, 'fiscal', [], sf.pool.get('adm.empresa.objeto').getEmpresa(
                cr, us, sf._name, context=cx), context=cx).get('fispar_nfe_indicador_presenca'),
        'fisnfc_nfe_indintermed': '0',
    }

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/fiscal/model/nota_fiscal_eletronica_data.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from openerp.osv import osv, fields
from funcoes import _fisnfc_get_dados_no_store
from funcoes_nfe import _fisnfc_get_indicador_presenca, _fisnfc_get_tempo_movimentacao_sefaz
from funcoes_nfe import _fisnfc_get_xml

FORMA_IMPRESSAO_DANFE =[
    ('0', 'Sem geração de DANFE'),
    ('1', 'Retrato'),
    ('2', 'Paisagem'),
    ('3', 'DANFE Simplificado'),
    ('4', 'DANFE NFC-e'),
    ('5', 'DANFE NFC-e em mensagem eletrônica')
]
PROCESSO_EMISSAO = [
    ('0', 'Emissao de NF com aplicativo proprio'),
    ('1', 'Emissao de NF avulsa pelo fisco'),
    ('2', 'Emissao de NF avulsa pelo site da SEFAZ'),
    ('3', 'Emissao de NF com aplicativo do fisco')
]
OPERACAO = [
    ('0', 'Operacao sem intermediador'),
    ('1', 'Operacao em site ou plataforma de terceiros'),
]


class fiscal_nf_capa(osv.Model):
    """
    Nota fiscal eletronica
    """
    def default_get(self, cr, uid, fields, context=None):
        context = context and context.copy() or {}
        res = super(fiscal_nf_capa, self).default_get(cr, uid, fields, context)
        if not context.get('import_nfe') and not context.get('nota_referenciada'):
            if res.get('modelo_nf_series_id') and res.get('nf_propria') or \
                    context.get('ctx_nf_propria'):
                nf_propria = self._fisnfc_nota_propria(cr, uid, context)
                vals = self.onchange_modelo_nf(
                    cr, uid, [], res['modelo_nf_series_id'], res['tipo'], nf_propria, context)
                res['modelo_55'] = vals['value'].get('modelo_55')
                if vals['value'].get('modelo_55'):
                    res['nfe_versao_processo_emissao'] = \
                        vals['value'].get('nfe_versao_processo_emissao')
                    res['nfe_forma_emissao'] = vals['value'].get('nfe_forma_emissao')
                    res['finalidade_emissao'] = vals['value'].get('finalidade_emissao')
                    res['nfe_processo_emissao'] = vals['value'].get('nfe_processo_emissao')
                    res['nfe_forma_impressao_danfe'] = \
                        vals['value'].get('nfe_forma_impressao_danfe')
                    res['fisnfc_nfe_status_configuracao_homologacao'] = \
                        vals['value'].get('fisnfc_nfe_status_configuracao_homologacao')
                    res['fisnfc_nfe_status_configuracao_producao'] = \
                        vals['value'].get('fisnfc_nfe_status_configuracao_producao')
        return res

    _inherit = 'fiscal.nf.capa'
    _columns = {
        'modelo_55': fields.boolean('modelo_55'),
        'gerar_xml': fields.boolean('gerar xml'),
        'finalidade_emissao': fields.selection(
            [('1', 'Normal'), ('2', 'Complementar'), ('3', 'Ajuste'),('4','Devolucao')],
            'Finalidade emissao', size=1),
        'fisnfc_nfe_indicador_presenca': fields.selection(
            _fisnfc_get_indicador_presenca, 'Indicador de presenca do comprador',
            type='char', size=1,
            help='Indicador de presenca do comprador no estabelecimento comercial no momento da '
                 'operacao.'),
        'nfe_lote': fields.char('Lote de autorizacao', size=15),
        'nfe_status': fields.char('Status NF-e', size=255),
        'nfe_xml_proc': fields.function(_fisnfc_get_xml, type='text'),
        'nfe_xml_auto': fields.text('XML de autorizacao'),
        'nfe_protocolo': fields.char('Protocolo de autorizacao', size=15),
        'nfe_xml_gerado': fields.text('XML da NF'),
        'nfe_chave_acesso': fields.char('Chave de acesso', size=44, select=1),
        'nfe_chave_cte': fields.char('Chave CT-e', size=44, select=1),
        'nfe_forma_emissao': fields.selection([
            ('1', 'Normal'), ('2', 'Contigencia'), ('9', 'Contigencia off-line NFC-e')], 'Nfe forma emissao', size=1, select=True),
        'nfe_xml_cancelamento': fields.text('Xml Cancelamento'),
        'nfe_processo_emissao': fields.selection(PROCESSO_EMISSAO, 'Nfe processo emissao', size=1),
        'nfe_forma_impressao_danfe': fields.selection(
            FORMA_IMPRESSAO_DANFE, 'Nfe forma impressao danfe', size=1),
        'nfe_protocolo_cancelamento': fields.char('Nfe Protocolo Cancelamento', size=15),
        'nfe_versao_processo_emissao': fields.char('Nfe versao processo emissao', size=20),
        'fisnfc_nfe_retorno_situacao_nfe': fields.text('XML Situacao NF-e'),
        'fisnfc_nfe_situacao_nfe_motivo': fields.text('Situacao NF-e'),
        'fisnfc_nfe_situacao_regular': fields.selection([
            ('R', 'Regular'), ('I', 'Irregular'), ('S', 'Sem Resposta')], 'Situacao NF-e', size=1),
        'fisnfc_nfe_xml_situacao_cliente': fields.text('Retorno XML Situacao Cliente'),
        'fisnfc_nfe_situacao_motivo': fields.text('Situacao Cliente'),
        'fisnfc_nfe_situacao_cliente': fields.selection([
            ('R', 'Regular'), ('I', 'Irregular'), ('S', 'Sem Resposta')], 'Situacao', size=1),
        'fisnfc_nfe_xml_correcao': fields.text('XML Correcao'),
        'fisnfc_nfe_protocolo_correcao': fields.char('Nfe Protocolo Correcao', size=15),
        'fisnfc_nfe_status_correcao': fields.text('Status Correcao'),
        'fisnfc_nfe_status_configuracao_homologacao': fields.text('Status NF-e Homologacao'),
        'fisnfc_nfe_status_configuracao_producao': fields.text('Status NF-e Producao'),
        'fisnfc_permissao_voltar_esboco': fields.function(
            _fisnfc_get_dados_no_store, type='boolean', method=True, multi='dados_no',
            string='Permissao para voltar para esboco'),
        'create_date': fields.datetime('Data de criacao', readonly=True),
        'write_date': fields.datetime('Data ultima alteracao', readonly=True),
        'nfe_observacao':fields.text('Observacoes da nota fiscal'),
        'nfe_tempo_movimentacao_sefaz': fields.function(
            _fisnfc_get_tempo_movimentacao_sefaz, method=True, digits=(3, 2),
            string='Tempo movimentacao SEFAZ',
            help='Informa o tempo decorrido em horas entre a primeira movimentacao e os demais '
                 'processos (inutilizacao, cancelamento, outros envios) envolvendo notas fiscais '
                 'eletronicas junto a SEFAZ.'),
        'fisnfc_evento_ids': fields.one2many('fiscal.evento', 'fiseve_nf_id', 'Evento', ondelete='cascade'),
        'fisnfc_nfe_indintermed': fields.selection(
            OPERACAO, 'Intermediador', size=1,
            help='Identifique se a operacao utiliza intermediadores'),
        'fisnfc_nfe_intermediador_cnpj': fields.char('CNPJ do intermediador', size=14),
        'fisnfc_nfe_intermediador_identificador': fields.char(
            'Identificador do intermediador', size=20),
    }
    _defaults = {
        'fisnfc_nfe_situacao_regular': 'S',
        'fisnfc_nfe_situacao_cliente': 'S',
        'nfe_status': '0',
        'gerar_xml': lambda *a: True,
        'nfe_processo_emissao': '0',
        'fisnfc_nfe_indicador_presenca': lambda sf, cr, us, cx: sf.pool.get(
            'adm.utils').admutl_get_parametros(
            cr, us, 'fiscal', [], sf.pool.get('adm.empresa.objeto').getEmpresa(
                cr, us, sf._name, context=cx), context=cx).get('fispar_nfe_indicador_presenca'),
        'fisnfc_nfe_indintermed': '0',
    }

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
